pub struct DeleteCapacityReservationFluentBuilder { /* private fields */ }Expand description
Fluent builder constructing a request to DeleteCapacityReservation.
Deletes a cancelled capacity reservation. A reservation must be cancelled before it can be deleted. A deleted reservation is immediately removed from your account and can no longer be referenced, including by its ARN. A deleted reservation cannot be called by GetCapacityReservation, and deleted reservations do not appear in the output of ListCapacityReservations.
Implementations
Sourceimpl DeleteCapacityReservationFluentBuilder
impl DeleteCapacityReservationFluentBuilder
Sourcepub fn as_input(&self) -> &DeleteCapacityReservationInputBuilder
pub fn as_input(&self) -> &DeleteCapacityReservationInputBuilder
Access the DeleteCapacityReservation as a reference.
Sourcepub async fn send(
self,
) -> Result<DeleteCapacityReservationOutput, SdkError<DeleteCapacityReservationError, HttpResponse>>
pub async fn send( self, ) -> Result<DeleteCapacityReservationOutput, SdkError<DeleteCapacityReservationError, HttpResponse>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
Sourcepub fn customize(
self,
) -> CustomizableOperation<DeleteCapacityReservationOutput, DeleteCapacityReservationError, Self>
pub fn customize( self, ) -> CustomizableOperation<DeleteCapacityReservationOutput, DeleteCapacityReservationError, Self>
Consumes this builder, creating a customizable operation that can be modified before being sent.
Sourcepub fn name(self, input: impl Into<String>) -> Self
pub fn name(self, input: impl Into<String>) -> Self
The name of the capacity reservation to delete.